pub enum RequesterPolicy {
AutoTune,
AutoBail,
Default,
}Expand description
represents actions the Requester should take in certain situations
Variants
AutoTune
automatically try to lower request rate in order to reduce errors
AutoBail
automatically bail at certain error thresholds
Default
just let that junk run super natural