pub enum OutputLevel {
Default,
Quiet,
Silent,
SilentJSON,
}Expand description
enum representing the three possible states for informational output (not logging verbosity)
Variants
Default
normal scan, no –quiet|–silent
Quiet
quiet scan, print some information, but not all (new in versions >= 2.0.0)
Silent
silent scan, only print urls (used to be –quiet in versions 1.x.x)
SilentJSON
silent scan, but with JSON output